@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,13 +8,9 @@
 
 using namespace KSieveUi;
 
-AbstractAkonadiImapSettingInterface::AbstractAkonadiImapSettingInterface()
-{
-}
+AbstractAkonadiImapSettingInterface::AbstractAkonadiImapSettingInterface() = default;
 
-AbstractAkonadiImapSettingInterface::~AbstractAkonadiImapSettingInterface()
-{
-}
+AbstractAkonadiImapSettingInterface::~AbstractAkonadiImapSettingInterface() = default;
 
 bool AbstractAkonadiImapSettingInterface::sieveSupport() const
 {
