@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef FINDACCOUNTINFOJOBTEST_H
-#define FINDACCOUNTINFOJOBTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -20,4 +19,3 @@ private Q_SLOTS:
     void shouldAssignValue_data();
     void shouldAssignValue();
 };
-#endif // FINDACCOUNTINFOJOBTEST_H
