@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,6 +12,4 @@ AbstractMoveImapFolderWidget::AbstractMoveImapFolderWidget(QWidget *parent)
 {
 }
 
-AbstractMoveImapFolderWidget::~AbstractMoveImapFolderWidget()
-{
-}
+AbstractMoveImapFolderWidget::~AbstractMoveImapFolderWidget() = default;
