@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,9 +12,7 @@ AbstractSelectEmailLineEdit::AbstractSelectEmailLineEdit(QWidget *parent)
 {
 }
 
-AbstractSelectEmailLineEdit::~AbstractSelectEmailLineEdit()
-{
-}
+AbstractSelectEmailLineEdit::~AbstractSelectEmailLineEdit() = default;
 
 bool AbstractSelectEmailLineEdit::multiSelection() const
 {
