@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,9 +15,7 @@ LineEditValidatorTest::LineEditValidatorTest(QObject *parent)
 {
 }
 
-LineEditValidatorTest::~LineEditValidatorTest()
-{
-}
+LineEditValidatorTest::~LineEditValidatorTest() = default;
 
 void LineEditValidatorTest::shouldHaveDefaultValue()
 {
